@@ -1,3 +1,7 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
+
 def config_to_rss_usage(self, config):
     # This table is used to translate names used by exploration tool, such as
     # 'tx_disable' to an RSS c-api equivalent. For example, 'acc_service_tx_disable_set' yields
@@ -33,7 +37,7 @@ def config_to_rss_usage(self, config):
         "range_interval": None,  # Not needed since we have range_start & range_length
         "range_end": None,  # --||--
         "mode": None,  # Not needed since we know what mode we are using
-        "sampling_mode": None,
+        "sampling_mode": "acc_service_{service}_sampling_mode_set",
     }
 
     # The exploration tool variables are not as the RSS c-api expects. Hence we need
