@@ -1,6 +1,9 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
-from typing import Any, Callable, Type
+from typing import Any, Callable, Generic, Optional, Type
 
 import attrs
 
@@ -9,17 +12,18 @@ import pyqtgraph as pg
 import acconeer.exptool as et
 from acconeer.exptool import a121
 from acconeer.exptool.a121 import algo
+from acconeer.exptool.a121.algo._base import ConfigT, InputT, MetadataT, ResultT
 from acconeer.exptool.app.new import GeneralMessage
 
 from ._null_app_model import NullAppModel
-from ._processor import ProcessorPlotPluginBase
+from .processor import GenericProcessorPlotPluginBase
 
 
 def processor_main(
     *,
-    processor_cls: Type[algo.ProcessorBase],
-    processor_config_cls: Type[algo.AlgoConfigBase],
-    plot_plugin: Type[ProcessorPlotPluginBase],
+    processor_cls: Type[algo.GenericProcessorBase[InputT, ConfigT, ResultT, MetadataT]],
+    processor_config_cls: Type[ConfigT],
+    plot_plugin: Type[GenericProcessorPlotPluginBase[ResultT, MetadataT]],
     sensor_config_getter: Callable[[], a121.SensorConfig],
 ) -> None:
     parser = a121.ExampleArgumentParser()
@@ -34,20 +38,19 @@ def processor_main(
     session_config = a121.SessionConfig({args.sensor: sensor_config})
 
     metadata = client.setup_session(session_config)
-    assert isinstance(metadata, a121.Metadata)
 
     processor_config = processor_config_cls()
 
     processor = processor_cls(
         sensor_config=sensor_config,
-        metadata=metadata,
+        metadata=metadata,  # type: ignore[arg-type]
         processor_config=processor_config,
     )
 
-    pg_updater = ProcessorPGUpdater(
+    pg_updater = ProcessorPGUpdater[ResultT, MetadataT](
         plot_plugin=plot_plugin,
         sensor_config=sensor_config,
-        metadata=metadata,
+        metadata=metadata,  # type: ignore[arg-type]
     )
     pg_process = et.PGProcess(pg_updater)  # type: ignore[attr-defined]
     pg_process.start()
@@ -59,9 +62,8 @@ def processor_main(
 
     while not interrupt_handler.got_signal:
         result = client.get_next()
-        assert isinstance(result, a121.Result)
 
-        processor_result = processor.process(result)
+        processor_result = processor.process(result)  # type: ignore[arg-type]
 
         try:
             pg_process.put_data(processor_result)
@@ -74,10 +76,13 @@ def processor_main(
 
 
 @attrs.mutable(kw_only=True, slots=False)
-class ProcessorPGUpdater:
-    plot_plugin: Type[ProcessorPlotPluginBase] = attrs.field()
+class ProcessorPGUpdater(Generic[ResultT, MetadataT]):
+    plot_plugin: Type[GenericProcessorPlotPluginBase[ResultT, MetadataT]] = attrs.field()
     sensor_config: a121.SensorConfig = attrs.field()
-    metadata: a121.Metadata = attrs.field()
+    metadata: MetadataT = attrs.field()
+    plot_plugin_obj: Optional[GenericProcessorPlotPluginBase[ResultT, MetadataT]] = attrs.field(
+        default=None, init=False
+    )
 
     def setup(self, win: pg.GraphicsLayout) -> None:
         self.plot_plugin_obj = self.plot_plugin(plot_layout=win, app_model=NullAppModel())
@@ -88,5 +93,8 @@ class ProcessorPGUpdater:
         )
 
     def update(self, data: Any) -> None:
+        if self.plot_plugin_obj is None:
+            raise RuntimeError
+
         self.plot_plugin_obj.handle_message(GeneralMessage(name="plot", data=data))
         self.plot_plugin_obj.draw()
