@@ -117,7 +117,7 @@ class DetectorConfig(AlgoConfigBase):
     )
     """Sorting method of estimated distances."""
 
-    num_frames_in_recorded_threshold: int = attrs.field(default=20)
+    num_frames_in_recorded_threshold: int = attrs.field(default=100)
     """Number of frames used when calibrating threshold."""
 
     fixed_threshold_value: float = attrs.field(default=DEFAULT_FIXED_THRESHOLD_VALUE)
@@ -746,7 +746,7 @@ class Detector:
             )
             rlg = signal_quality + 40 * np.log10(subsweep_end_point_m) - np.log10(processing_gain)
             hwaas_in_subsweep = int(10 ** ((rlg - rlg_per_hwaas) / 10))
-            hwaas.append(np.max(hwaas_in_subsweep, 0))
+            hwaas.append(np.clip(hwaas_in_subsweep, cls.MIN_HWAAS, cls.MAX_HWAAS))
         return hwaas
 
     @staticmethod
