@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
 import abc
@@ -138,6 +141,7 @@ class AppModel(QObject):
     backend_plugin_state: Any
 
     connection_state: ConnectionState
+    connection_warning: Optional[str]
     connection_interface: ConnectionInterface
     plugin_state: PluginState
     socket_connection_ip: str
@@ -166,6 +170,7 @@ class AppModel(QObject):
         self.backend_plugin_state = None
 
         self.connection_state = ConnectionState.DISCONNECTED
+        self.connection_warning = None
         self.connection_interface = ConnectionInterface.SERIAL
         self.plugin_state = PluginState.UNLOADED
         self.socket_connection_ip = ""
@@ -272,6 +277,7 @@ class AppModel(QObject):
         if isinstance(message, ConnectionStateMessage):
             log.debug("Got backend connection state message")
             self.connection_state = message.state
+            self.connection_warning = message.warning
             self.broadcast()
         elif isinstance(message, PluginStateMessage):
             log.debug("Got backend plugin state message")
@@ -346,16 +352,32 @@ class AppModel(QObject):
         tagged_ports: list[Tuple[str, Optional[str]]],
         usb_devices: Optional[list[USBDevice]],
     ) -> None:
+        tagged_ports_map = dict(tagged_ports)
+        if self.connection_state is not ConnectionState.DISCONNECTED and (
+            (
+                self.connection_interface == ConnectionInterface.SERIAL
+                and self.serial_connection_port not in tagged_ports_map.keys()
+            )
+            or (
+                self.connection_interface == ConnectionInterface.USB
+                and usb_devices
+                and self.usb_connection_device not in usb_devices
+            )
+        ):
+            self.disconnect_client()
         self.serial_connection_port, recognized = self._select_new_serial_port(
             dict(self.available_tagged_ports),
-            dict(tagged_ports),
+            tagged_ports_map,
             self.serial_connection_port,
         )
+
         self.available_tagged_ports = tagged_ports
+        connect = False
 
         if recognized:
             self.set_connection_interface(ConnectionInterface.SERIAL)
             self.send_status_message(f"Recognized serial port: {self.serial_connection_port}")
+            connect = True
 
         if usb_devices is not None:
             self.usb_connection_device, recognized = self._select_new_usb_device(
@@ -368,9 +390,16 @@ class AppModel(QObject):
                 assert self.usb_connection_device is not None
                 self.set_connection_interface(ConnectionInterface.USB)
                 self.send_status_message(f"Recognized USB device: {self.usb_connection_device}")
+                connect = True
+
+        if connect:
+            self._autoconnect()
 
         self.broadcast()
 
+    def _autoconnect(self) -> None:
+        self.connect_client(auto=True)
+
     def _select_new_serial_port(
         self,
         old_ports: dict[str, Optional[str]],
@@ -385,7 +414,7 @@ class AppModel(QObject):
 
             for port, tag in new_ports.items():
                 if tag:
-                    return port, False
+                    return port, (current_port is None)
 
             return port, False
 
@@ -403,7 +432,7 @@ class AppModel(QObject):
 
     def _select_new_usb_device(
         self,
-        new_ports: list[str],
+        new_ports: list[USBDevice],
         current_port: Optional[USBDevice],
     ) -> Tuple[Optional[USBDevice], bool]:
         if self.connection_state != ConnectionState.DISCONNECTED:
@@ -417,7 +446,7 @@ class AppModel(QObject):
 
         return current_port, False
 
-    def connect_client(self) -> None:
+    def connect_client(self, auto: bool = False) -> None:
         if self.connection_interface == ConnectionInterface.SOCKET:
             client_info = a121.ClientInfo(ip_address=self.socket_connection_ip)
         elif self.connection_interface == ConnectionInterface.SERIAL:
@@ -429,17 +458,23 @@ class AppModel(QObject):
 
         log.debug(f"Connecting client with {client_info}")
 
+        on_error = self.emit_error
+        if auto:
+            on_error = self._failed_autoconnect
+
         self._put_backend_task(
             "connect_client",
             {"client_info": client_info},
-            on_error=self.emit_error,
+            on_error=on_error,
         )
         self.connection_state = ConnectionState.CONNECTING
+        self.connection_warning = None
         self.broadcast()
 
     def disconnect_client(self) -> None:
         self._put_backend_task("disconnect_client", {})
         self.connection_state = ConnectionState.DISCONNECTING
+        self.connection_warning = None
         self._a121_server_info = None
         self.broadcast()
 
@@ -456,6 +491,11 @@ class AppModel(QObject):
             )
         )
 
+    def _failed_autoconnect(
+        self, exception: Exception, traceback_format_exc: Optional[str] = None
+    ) -> None:
+        self.send_status_message('<p style="color: #FD5200;"><b>Failed to autoconnect</b></p>')
+
     def set_connection_interface(self, connection_interface: ConnectionInterface) -> None:
         self.connection_interface = connection_interface
         self.broadcast()
