@@ -1,9 +1,17 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 """This script checks whether CHANGELOG refers to the same version as the current git tag."""
+
+from __future__ import annotations
+
 import re
 import subprocess
 from pathlib import Path
 from typing import Optional
 
+from packaging.version import Version
+
 
 def utf8_subprocess_output(*args: str):
     return subprocess.check_output(args, encoding="utf-8").strip()
@@ -49,6 +57,9 @@ def main():
     if not is_current_commit_tagged:
         exit(0)
 
+    if Version(most_recent_tag).is_prerelease:
+        exit(0)
+
     print(f"Current commit ({current_commit_sha[:7]}) is tagged ({most_recent_tag}).")
 
     changelog = Path(FILE_PATH)
